@@ -4,8 +4,8 @@ from users_and_computers.models import RiskAssignment
 
 
 class RiskVMPanel(PluginTemplateExtension):
-    # model = 'users_and_computers.risk'
-    model = 'virtualization.virtualmachine'
+    model = 'plugins.users_and_computers.risk'
+    # model = 'virtualization.virtualmachine'
 
     def right_page(self):
         vm = self.context['object']
@@ -26,9 +26,8 @@ class RiskVMPanel(PluginTemplateExtension):
 
 
 class RiskDevicePanel(PluginTemplateExtension):
-    # model = 'users_and_computers.RiskRelation'
-    model = 'dcim.device'
-    # model = 'users_and_computers.riskrelation'
+    # model = 'dcim.device'
+    model = 'plugins.users_and_computers.riskrelation'
 
     def right_page(self):
         risk = self.context['object']
